ping — Breezy 3.0.2dev documentation

Table of Contents (3.0.2dev)

# ping

Purpose

  Pings a Bazaar smart server.

Usage

  brz ping LOCATION

Options
  `-h, --help`

    Show help message.

  `-q, --quiet`

    Only display errors and warnings.

  `--usage`

    Show usage message and options.

  `-v, --verbose`

    Display more information.

Description

  This command sends a ‘hello’ request to the given location using the brz smart protocol, and reports the response.